Module content

Module content 

Structured content nodes — the output of Content.render().

ContentNode is a rich, structured representation of rendered output that supports styled text, tables, code blocks, charts, key-value pairs, and fragments (compositions of multiple nodes).

Structs

ChartSeries
ChartSpec
ContentTable
Style
StyledSpan
StyledText

Enums

BorderStyle
ChartType
Color
ContentNode
A structured content node — the output of Content.render()
NamedColor