shape_for_hashmap_keys

Function shape_for_hashmap_keys 

pub fn shape_for_hashmap_keys(key_hashes: &[u32]) -> Option<ShapeId>
Compute a ShapeId for a HashMap with the given key hashes (in insertion order).

Consults the ambient shape table (see module docs). Returns None if no scope is active, if the lock is poisoned, or if there are more than 64 properties (dictionary mode threshold).