TypedClosureHeader

Struct TypedClosureHeader 

#[repr(C)]
pub struct TypedClosureHeader { pub header: HeapHeader, pub function_id: u32, pub type_id: u32, }
Heap-allocated closure. The HeapHeader is at offset 0; captures follow the function_id/type_id pair at offset 16.

This is a layout marker used by JIT/VM codegen — captures are not declared as Rust fields because their number and types are only known per ClosureTypeId.

Fields

header: HeapHeaderfunction_id: u32type_id: u32