StructFieldLayout

Struct StructFieldLayout 

pub struct StructFieldLayout {
    pub name: String,
    pub offset: u32,
    pub size: u32,
    pub field_type: FieldType,
}
Layout information for a single field within a struct.

Fields

name: String

Field name (e.g. "x").

offset: u32

Byte offset from the start of the struct (including header).

size: u32

Size of this field in bytes.

field_type: FieldType

The primitive type of this field.