pub struct HostCallable { /* private fields */ }Expand description
A callable closure backed by native Rust code with captured state. Used by extension modules to return objects with callable methods (e.g., DbTable.filter).
Implementations