Structured content nodes — the output of Content.render().
ContentNode is a rich, structured representation of rendered output that supports styled text, tables, code blocks, charts, key-value pairs, and fragments (compositions of multiple nodes).
Structs
Enums
- Border
Style - Chart
Type - Color
- Content
Node - A structured content node — the output of Content.render()
- Named
Color