pub struct StructFieldLayout {
pub name: String,
pub offset: u32,
pub size: u32,
pub field_type: FieldType,
}Expand description
Layout information for a single field within a struct.
Fields
name: StringField name (e.g. "x").
offset: u32Byte offset from the start of the struct (including header).
size: u32Size of this field in bytes.
field_type: FieldTypeThe primitive type of this field.